@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Minio Python Library for Amazon S3 Compatible Cloud Storage,
-# (C) 2015, 2016, 2017, 2018 Minio, Inc.
+# MinIO Python Library for Amazon S3 Compatible Cloud Storage,
+# (C) 2015, 2016, 2017, 2018 MinIO, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -678,9 +678,10 @@ def validate_stat_data(st_obj, expected_size, expected_meta):
     if not received_etag or received_etag == '':
         raise ValueError('No Etag value is returned.')
 
-    if received_content_type != 'application/octet-stream':
+    # content_type by default can be either application/octet-stream or binary/octet-stream
+    if received_content_type != 'application/octet-stream' and received_content_type != 'binary/octet-stream':
         raise ValueError('Incorrect content type. Expected: ',
-                         "'application/octet-stream', received: ",
+                         "'application/octet-stream' or 'binary/octet-stream', received: ",
                           received_content_type)
 
     if received_size != expected_size:
@@ -1730,9 +1731,9 @@ def main():
         access_key = os.getenv('ACCESS_KEY', 'Q3AM3UQ867SPQQA43P2F')
         secret_key = os.getenv('SECRET_KEY',
                                'zuf+tfteSlswRu7BJ86wekitnifILbZam1KYY3TG')
-        server_endpoint = os.getenv('SERVER_ENDPOINT', 'play.minio.io:9000')
+        server_endpoint = os.getenv('SERVER_ENDPOINT', 'play.min.io:9000')
         secure = os.getenv('ENABLE_HTTPS', '1') == '1'
-        if server_endpoint == 'play.minio.io:9000':
+        if server_endpoint == 'play.min.io:9000':
             access_key = 'Q3AM3UQ867SPQQA43P2F'
             secret_key = 'zuf+tfteSlswRu7BJ86wekitnifILbZam1KYY3TG'
             secure = True
